@@ -1,4 +1,4 @@
-from vasp_suite.main import *
+from vasp_suite.cli import *
 """
 This is a package for generating input and submission files for vasp calculations
-"""
\ No newline at end of file
+"""
